@@ -14,13 +14,7 @@
 import croniter
 import eventlet
 import netaddr
-
-try:
-    import zoneinfo
-except ImportError:
-    # zoneinfo is available in Python >= 3.9
-    import pytz
-    zoneinfo = None
+import zoneinfo
 
 from neutron_lib.api import validators
 from oslo_utils import timeutils
@@ -173,10 +167,7 @@ class TimezoneConstraint(constraints.BaseCustomConstraint):
         if not value:
             return True
         try:
-            if zoneinfo:
-                zoneinfo.ZoneInfo(value)
-            else:
-                pytz.timezone(value)
+            zoneinfo.ZoneInfo(value)
             return True
         except Exception as ex:
             self._error_message = _(
