@@ -112,7 +112,7 @@ class ExtraRouteSet(neutron.NeutronResource):
 
     def add_dependencies(self, deps):
         super(ExtraRouteSet, self).add_dependencies(deps)
-        for resource in self.stack.items():
+        for resource in self.stack.values():
             # depend on any RouterInterface in this template with the same
             # router as this router
             if resource.has_interface('OS::Neutron::RouterInterface'):
