@@ -12,12 +12,11 @@
 #    under the License.
 
 import datetime
+from unittest import mock
 import uuid
 
-import mock
 from oslo_serialization import jsonutils as json
 from oslo_utils import timeutils
-import six
 
 from heat.common import identifier
 from heat.common import template_format
@@ -26,6 +25,7 @@ from heat.engine.clients.os import swift as swift_plugin
 from heat.engine import environment
 from heat.engine import resource
 from heat.engine.resources.openstack.heat import wait_condition_handle as h_wch
+from heat.engine import scheduler
 from heat.engine import stack as parser
 from heat.engine import template as tmpl
 from heat.objects import resource as resource_objects
@@ -262,7 +262,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
 
         wc_att = rsrc.FnGetAtt('data')
-        self.assertEqual(six.text_type({}), wc_att)
+        self.assertEqual(str({}), wc_att)
 
         handle = self.stack['wait_handle']
         self.assertEqual((handle.CREATE, handle.COMPLETE), handle.state)
@@ -490,5 +490,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
 
         handle = self.stack['update_wait_handle']
         self.assertEqual((handle.CREATE, handle.COMPLETE), handle.state)
+
         self.assertRaises(
-            resource.UpdateReplace, handle.update, None, None)
+            resource.UpdateReplace,
+            scheduler.TaskRunner(handle.update, handle.t))
